# CoCiP-Fortran comparison tests

Comparison data for two test flights in the North Atlantic 2019-01-05.

Input/output data stored in [gs://contrails-301217-benchmark-data-archive/cocip-fortran](https://console.cloud.google.com/storage/browser/contrails-301217-benchmark-data/cocip-fortran?) (public).

Requires [Google Cloud SDK](https://cloud.google.com/sdk/docs/install) installed to download data.

Comparison performed by Imperial and DLR between January and February 2023.
Outputs referenced here generated by Roger Teoh.

## Data


Download output data for model comparison from gcp bucket to local `outputs/` directory. 
From the current directory:

```bash
$ gsutil -m cp -r gs://contrails-301217-benchmark-data-archive/cocip-fortran/outputs .
```


## Update

To update the reference data in the bucket

```bash
$ gsutil rsync -x ".DS_Store" -d -r outputs/ gs://contrails-301217-benchmark-data-archive/cocip-fortran/outputs
```
